@@ -1,7 +1,7 @@
 import requests
 
 class Rella:
-  def __init__(self, api_key, enabled=True, ingest_url="https://ingestion.rella.so/events/i"):
+  def __init__(self, api_key, enabled=True, ingest_url="https://ingestion.rella.so/i/events"):
     self.api_key = api_key
     self.enabled = enabled
     self.ingest_url = ingest_url
